Pluggy.Connect.Kino (PluggyAI v0.1.0)

Copy Markdown View Source

Pluggy Connect widget for Livebook using Kino.JS.Live.

Renders the Pluggy Connect widget inline in a Livebook cell and pushes the connected item data back to Elixir when the user completes the connection flow.

Usage

With a client (generates the connect token automatically):

{:ok, client} = Pluggy.Client.new("client_id", "client_secret")
widget = Pluggy.Connect.Kino.new(client, include_sandbox: true)

Or with an existing connect token:

{:ok, token} = Pluggy.Client.connect_token(client)
widget = Pluggy.Connect.Kino.new(token, include_sandbox: true)

After the user connects a bank account in the widget:

item = Pluggy.Connect.Kino.await_item(widget)

Requires the :kino dependency.

Summary

Functions

Blocks until the user completes the widget connection and returns the item data.

Creates a new Pluggy Connect widget.

Functions

await_item(widget)

Blocks until the user completes the widget connection and returns the item data.

new(token_or_client, opts \\ [])

Creates a new Pluggy Connect widget.

Options

  • :include_sandbox — show sandbox connectors (default false)

Examples

widget = Pluggy.Connect.Kino.new(client)
widget = Pluggy.Connect.Kino.new(client, include_sandbox: true)
widget = Pluggy.Connect.Kino.new("connect_token_string")