An opaque cursor for paginated API responses.
Holds a fetcher function and the next page number. Pass to
Pluggy.HTTP.next/1 to fetch the next page.
Summary
Types
@type t() :: %Pluggy.HTTP.Cursor{fetcher: Pluggy.HTTP.fetcher(), page: pos_integer()}
An opaque cursor for paginated API responses.
Holds a fetcher function and the next page number. Pass to
Pluggy.HTTP.next/1 to fetch the next page.
@type t() :: %Pluggy.HTTP.Cursor{fetcher: Pluggy.HTTP.fetcher(), page: pos_integer()}